#include "spi_flash_block.h"

#define NRF_LOG_MODULE_NAME spi_flash_block
#include "nrf_log.h"
#include "nrf_log_ctrl.h"
NRF_LOG_MODULE_REGISTER();

#include <stdbool.h>
#include <stdint.h>
#include "app_error.h"
#include "app_util_platform.h"
#include "sdk_config.h"
#include "spi_flash.h"


static bool m_is_init = false;

void spi_flash_block_init(void)
{
    if (m_is_init) return;

    spi_flash_init();
    m_is_init = true;
}

void spi_flash_block_uninit(void)
{
    if (!m_is_init) return;

    m_is_init = false;
    spi_flash_uninit();  
}

ret_code_t spi_flash_block_read_data(uint32_t addr, void *buff, uint32_t len)
{
    ret_code_t err_code = NRF_SUCCESS;

    if (!m_is_init)
    {
        err_code = NRF_ERROR_INVALID_STATE;
    }
    else if (addr >= FLASH_SIZE || addr + len >= FLASH_SIZE)
    {
        err_code = NRF_ERROR_INVALID_PARAM;
    }
    else
    {
        err_code = spi_flash_read_data(addr);

        if (err_code == NRF_SUCCESS)
        {
            err_code = spi_flash_data_get(buff, len);
        }
    }

    return err_code;
}
